import { z } from "zod";
export declare const interestRatesQuerySchema: z.ZodObject<{
    correlationId: z.ZodOptional<z.ZodString>;
    interestGroupCode: z.ZodOptional<z.ZodString>;
    date: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
    countryIds: z.ZodString;
    businessAreaIds: z.ZodString;
}, "strip", z.ZodTypeAny, {
    countryIds: string;
    businessAreaIds: string;
    correlationId?: string | undefined;
    interestGroupCode?: string | undefined;
    date?: string | undefined;
}, {
    countryIds: string;
    businessAreaIds: string;
    correlationId?: string | undefined;
    interestGroupCode?: string | undefined;
    date?: string | undefined;
}>;
export type InterestRatesQueryRequest = z.infer<typeof interestRatesQuerySchema>;
export interface InterestRatesResponse {
    correlationId: string;
    result: boolean;
    resultInterestRate: {
        interestRates: {
            rateCode: string;
            fromDate: string;
            rateValue: number;
        }[];
        rateCount: number;
    };
    serviceVersion: string;
}
export declare const loanToValueQuerySchema: z.ZodObject<{
    correlationId: z.ZodOptional<z.ZodString>;
    productCode: z.ZodOptional<z.ZodString>;
    countryIds: z.ZodString;
    businessAreaIds: z.ZodString;
}, "strip", z.ZodTypeAny, {
    countryIds: string;
    businessAreaIds: string;
    correlationId?: string | undefined;
    productCode?: string | undefined;
}, {
    countryIds: string;
    businessAreaIds: string;
    correlationId?: string | undefined;
    productCode?: string | undefined;
}>;
export type LoanToValueQueryRequest = z.infer<typeof loanToValueQuerySchema>;
export interface LoanToValueResponse {
    correlationId: string;
    result: boolean;
    resultLTV: {
        loanToValueRatioForProduct: {
            productCode: string;
            groupCode: string;
            fromRatio: number;
        }[];
        entryCount: number;
    };
    serviceVersion: string;
}
export declare const objectDetailsQuerySchema: z.ZodUnion<[z.ZodObject<{
    municipalityNumber: z.ZodString;
    cadastralUnitNumber: z.ZodString;
    unitNumber: z.ZodString;
    leaseholdUnitNumber: z.ZodString;
    sectionNumber: z.ZodString;
}, "strip", z.ZodTypeAny, {
    municipalityNumber: string;
    cadastralUnitNumber: string;
    unitNumber: string;
    leaseholdUnitNumber: string;
    sectionNumber: string;
}, {
    municipalityNumber: string;
    cadastralUnitNumber: string;
    unitNumber: string;
    leaseholdUnitNumber: string;
    sectionNumber: string;
}>, z.ZodObject<{
    organizationNumber: z.ZodString;
    shareNumber: z.ZodString;
}, "strip", z.ZodTypeAny, {
    organizationNumber: string;
    shareNumber: string;
}, {
    organizationNumber: string;
    shareNumber: string;
}>]>;
export type ObjectDetailsQueryRequest = z.infer<typeof objectDetailsQuerySchema>;
type AccountInfo = {
    sourceSystemCode: string;
    sourceApplicationID: string;
    coreAccountNo: string;
    mainContactNo: string;
    mainContactLegalID: string;
    mainContactName: string;
    coSignerContactNo: string;
    coSignerLegalID: string;
    coSignerName: string;
    accountType: string;
    accountSubtype: string;
    accountDescription: string;
    externalProductID: string;
    accountStatusGroup: string;
    accountStatus: string;
    startDate: string;
    disbursementBankAccountNo: string;
};
type SecurityInfo = {
    coreSecurityID: string;
    objectId: string;
    faceValue: number;
    type: string;
    registrationDocumentNo: string;
    registrationDocumentYear: string;
    registrationOfficeNo: string;
    registrationRightNo: string;
    accountInfo: AccountInfo[];
};
type ObjectInfo = {
    coreObjectNo: string;
    objectPropertyAddress: string;
    objectPropertyZip: string;
    objectPropertyLandNo: string;
    objectPropertyLeaseNo: string;
    objectPropertyMunicipalNo: string;
    objectPropertyOrgNo: string;
    objectPropertySectionNo: string;
    objectPropertyShareNo: string;
    objectPropertyUnitNo: string;
    objectSubClassCode: string;
    depotLastValuationDate: string;
    depotAdjustmentSource: string;
    depotValidUntil: string;
    depotMunicipalityScore: number;
    depotAreaScore: number;
    depotAreaVacationScore: number;
    depotCommonDebt: number;
    depotCommonDebtDate: string;
    depotDepreciationFactor: number;
    depotValue: number;
    depotValueFactor: number;
    objectClassCode: string;
    objectConditionCode: number;
    securityInfo: SecurityInfo[];
};
export interface ObjectDetailsResponse {
    correlationId: string;
    resultObjectDetails: {
        objectInfo: ObjectInfo[];
        objectInfoCount: number;
    };
    serviceVersion: string;
    result: boolean;
}
export {};
